==> qcad-3.32.4.0-1-x86_64.pkg.tar.zst: usr/lib/qcad/ts/qcadgui_lv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lv_LV">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation type="unfinished">Vertikāli/horizontāli</translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation type="unfinished">Atpakaļ</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation type="unfinished">Pielāgots</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation type="unfinished">Tīkls</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation type="unfinished">Izbeigt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation type="unfinished">Par vienību</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation type="unfinished">Perpendikulāri</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation type="unfinished">Tangenciālais</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation type="unfinished">Centrs</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation type="unfinished">Middle</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation type="unfinished">Krustojums</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation type="unfinished">Atsauce</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation type="unfinished">Attālums</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation type="unfinished">Nederīgs</translation>
    </message>
</context>
</TS>

==> qcad-3.32.5.0-1-x86_64.pkg.tar.zst: usr/lib/qcad/ts/qcadgui_lv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lv_LV">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation>Vertikāli/horizontāli</translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation>Atpakaļ</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation>Pielāgots</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation>Tīkls</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Izbeigt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>Par vienību</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>Perpendikulāri</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>Tangenciālais</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Centrs</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Middle</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Krustojums</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Atsauce</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation>Attālums</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation>Nederīgs</translation>
    </message>
</context>
</TS>
